@@ -1,6 +1,7 @@
 package Net::Stripe;
-$Net::Stripe::VERSION = '0.30';
+$Net::Stripe::VERSION = '0.31';
 use Moose;
+use Class::Load;
 use Kavorka;
 use LWP::UserAgent;
 use HTTP::Request::Common qw/GET POST DELETE/;
@@ -703,7 +704,9 @@ sub _hash_to_object {
         my @words  = map { ucfirst($_) } split('_', $hash->{object});
         my $object = join('', @words);
         my $class  = 'Net::Stripe::' . $object;
-        return $class->new($hash);
+        if (Class::Load::is_class_loaded($class)) {
+          return $class->new($hash);
+        }
     }
     return $hash;
 }
@@ -730,7 +733,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -748,7 +751,7 @@ version 0.30
  # look up a charge by id
  my $same_charge = $stripe->get_charge(charge_id => $charge->id);
 
- # ... and the api mirrors https://stripe.com/docs/api
+ # ... and the API mirrors https://stripe.com/docs/api
  # Charges: post_charge() get_charge() refund_charge() get_charges()
  # Customer: post_customer()
 
@@ -763,7 +766,7 @@ This method returns Moose objects for responses from the API.
 
 =head2 new PARAMHASH
 
-This creates a new stripe api object.  The following parameters are accepted:
+This creates a new stripe API object.  The following parameters are accepted:
 
 =over
 
@@ -781,59 +784,11 @@ You can set this to true to see the actual network requests.
 
 =back
 
-=head1 ATTRIBUTES
-
-=head2 api_base
-
-Reader: api_base
-
-Type: Str
-
-Additional documentation: This is the base part of the URL for every request made
-
-=head2 api_key
-
-Reader: api_key
-
-Type: Str
-
-This attribute is required.
-
-Additional documentation: You get this from your Stripe Account settings
-
-=head2 debug
-
-Reader: debug
-
-Writer: debug
-
-Type: Bool
-
-Additional documentation: The debug flag
-
-=head2 debug_network
-
-Reader: debug_network
-
-Writer: debug_network
-
-Type: Bool
-
-Additional documentation: The debug network request flag
-
-=head2 ua
-
-Reader: ua
-
-Type: Object
-
-Additional documentation: The LWP::UserAgent that is used for requests
-
 =head1 Balance Transaction Methods
 
 =head2 get_balance_transaction
 
-Retrieve a balance transaction
+Retrieve a balance transaction.
 
 L<https://stripe.com/docs/api#retrieve_balance_transaction>
 
@@ -843,7 +798,7 @@ L<https://stripe.com/docs/api#retrieve_balance_transaction>
 
 =back
 
-Returns a L<Net::Stripe::BalanceTransaction>
+Returns a L<Net::Stripe::BalanceTransaction>.
 
   $stripe->get_balance_transaction(id => 'id');
 
@@ -851,7 +806,7 @@ Returns a L<Net::Stripe::BalanceTransaction>
 
 =head2 post_charge
 
-Create a new charge
+Create a new charge.
 
 L<https://stripe.com/docs/api#create_charge>
 
@@ -877,7 +832,7 @@ L<https://stripe.com/docs/api#create_charge>
 
 =back
 
-Returns L<Net::Stripe::Charge>
+Returns L<Net::Stripe::Charge>.
 
   $stripe->post_charge(currency => 'USD', amount => 500, customer => 'testcustomer');
 
@@ -893,15 +848,15 @@ L<https://stripe.com/docs/api#retrieve_charge>
 
 =back
 
-Returns L<Net::Stripe::Charge>
+Returns L<Net::Stripe::Charge>.
 
   $stripe->get_charge(charge_id => 'chargeid');
 
 =head2 refund_charge
 
-Refunds a charge
+Refunds a charge.
 
-L<https://stripe.com/docs/api#refund_charge>
+L<https://stripe.com/docs/api#create_refund>
 
 =over
 
@@ -971,7 +926,7 @@ L<https://stripe.com/docs/api#create_customer>
 
 =back
 
-Returns a L<Net::Stripe::Customer> object
+Returns a L<Net::Stripe::Customer> object.
 
   my $customer = $stripe->post_customer(
     card => $fake_card,
@@ -981,7 +936,7 @@ Returns a L<Net::Stripe::Customer> object
 
 =head2 list_subscriptions
 
-Returns the subscriptions for a customer
+Returns the subscriptions for a customer.
 
 L<https://stripe.com/docs/api#list_subscriptions>
 
@@ -997,11 +952,11 @@ L<https://stripe.com/docs/api#list_subscriptions>
 
 =back
 
-Returns a list of L<Net::Stripe::Subscription> objects
+Returns a list of L<Net::Stripe::Subscription> objects.
 
 =head2 get_customer
 
-Retrieve a customer
+Retrieve a customer.
 
 L<https://stripe.com/docs/api#retrieve_customer>
 
@@ -1017,7 +972,7 @@ Returns a L<Net::Stripe::List> object containing L<Net::Stripe::Customer> object
 
 =head2 delete_customer
 
-Delete a customer
+Delete a customer.
 
 L<https://stripe.com/docs/api#delete_customer>
 
@@ -1027,7 +982,7 @@ L<https://stripe.com/docs/api#delete_customer>
 
 =back
 
-Returns a L<Net::Stripe::Customer> object
+Returns a L<Net::Stripe::Customer> object.
 
   $stripe->delete_customer(customer => $customer);
 
@@ -1069,13 +1024,13 @@ L<https://stripe.com/docs/api#retrieve_card>
 
 =back
 
-Returns a L<Net::Stripe::Card>
+Returns a L<Net::Stripe::Card>.
 
   $stripe->get_card(customer => 'customer_id', card_id => 'abcdef');
 
 =head2 post_card
 
-Create or update a card
+Create or update a card.
 
 L<https://stripe.com/docs/api#create_card>
 
@@ -1087,13 +1042,13 @@ L<https://stripe.com/docs/api#create_card>
 
 =back
 
-Returns a L<Net::Stripe::Card>
+Returns a L<Net::Stripe::Card>.
 
   $stripe->create_card(customer => $customer, card => $card);
 
 =head2 get_cards
 
-Returns a list of cards
+Returns a list of cards.
 
 L<https://stripe.com/docs/api#list_cards>
 
@@ -1163,13 +1118,13 @@ L<https://stripe.com/docs/api#create_subscription>
 
 =back
 
-Returns a L<Net::Stripe::Customer> object
+Returns a L<Net::Stripe::Customer> object.
 
   $stripe->post_subscription(customer => $customer, plan => 'testplan');
 
 =head2 get_subscription
 
-Returns a customers subscription
+Returns a customer's subscription.
 
 =over
 
@@ -1177,13 +1132,13 @@ Returns a customers subscription
 
 =back
 
-Returns a L<Net::Stripe::Subscription>
+Returns a L<Net::Stripe::Subscription>.
 
   $stripe->get_subscription(customer => 'test123');
 
 =head2 delete_subscription
 
-Cancel a customer's subscription
+Cancel a customer's subscription.
 
 L<https://stripe.com/docs/api#cancel_subscription>
 
@@ -1205,7 +1160,7 @@ Returns a L<Net::Stripe::Subscription> object.
 
 =head2 post_token
 
-Create a new token
+Create a new token.
 
 L<https://stripe.com/docs/api#create_card_token>
 
@@ -1215,13 +1170,13 @@ L<https://stripe.com/docs/api#create_card_token>
 
 =back
 
-Returns a L<Net::Stripe::Token>
+Returns a L<Net::Stripe::Token>.
 
   $stripe->post_token(card => $test_card);
 
 =head2 get_token
 
-Retreives an existing token.
+Retrieves an existing token.
 
 L<https://stripe.com/docs/api#retrieve_token>
 
@@ -1231,7 +1186,7 @@ L<https://stripe.com/docs/api#retrieve_token>
 
 =back
 
-Returns a L<Net::Stripe::Token>
+Returns a L<Net::Stripe::Token>.
 
   $stripe->get_token(token_id => 'testtokenid');
 
@@ -1239,7 +1194,7 @@ Returns a L<Net::Stripe::Token>
 
 =head2 post_plan
 
-Create a new plan
+Create a new plan.
 
 L<https://stripe.com/docs/api#create_plan>
 
@@ -1263,7 +1218,7 @@ L<https://stripe.com/docs/api#create_plan>
 
 =back
 
-Returns a L<Net::Stripe::Plan> object
+Returns a L<Net::Stripe::Plan> object.
 
   $stripe->post_plan(
      id => "free-$future_ymdhms",
@@ -1283,7 +1238,7 @@ Retrieves a plan.
 
 =back
 
-Returns a L<Net::Stripe::Plan>
+Returns a L<Net::Stripe::Plan>.
 
   $stripe->get_plan(plan_id => 'plan123');
 
@@ -1299,13 +1254,13 @@ L<https://stripe.com/docs/api#delete_plan>
 
 =back
 
-Returns a L<Net::Stripe::Plan> object
+Returns a L<Net::Stripe::Plan> object.
 
   $stripe->delete_plan(plan_id => $plan);
 
 =head2 get_plans
 
-Return a list of Plans
+Return a list of plans.
 
 L<https://stripe.com/docs/api#list_plans>
 
@@ -1327,7 +1282,7 @@ Returns a L<Net::Stripe::List> object containing L<Net::Stripe::Plan> objects.
 
 =head2 post_coupon
 
-Create or update a coupon
+Create or update a coupon.
 
 L<https://stripe.com/docs/api#create_coupon>
 
@@ -1365,7 +1320,7 @@ Returns a L<Net::Stripe::Coupon> object.
 
 =head2 get_coupon
 
-Retreive a coupon
+Retrieve a coupon.
 
 L<https://stripe.com/docs/api#retrieve_coupon>
 
@@ -1381,7 +1336,7 @@ Returns a L<Net::Stripe::Coupon> object.
 
 =head2 delete_coupon
 
-Delete a coupon
+Delete a coupon.
 
 L<https://stripe.com/docs/api#delete_coupon>
 
@@ -1391,7 +1346,7 @@ L<https://stripe.com/docs/api#delete_coupon>
 
 =back
 
-Returns a L<Net::Stripe::Coupon>
+Returns a L<Net::Stripe::Coupon>.
 
   $stripe->delete_coupon(coupon_id => 'coupon123');
 
@@ -1415,7 +1370,7 @@ Returns a L<Net::Stripe::List> object containing L<Net::Stripe::Coupon> objects.
 
 =head2 post_invoice
 
-Update an invoice
+Update an invoice.
 
 =over
 
@@ -1431,7 +1386,7 @@ Update an invoice
 
 =back
 
-Returns a L<Net::Stripe::Invoice>
+Returns a L<Net::Stripe::Invoice>.
 
   $stripe->post_invoice(invoice => $invoice, closed => 'true')
 
@@ -1443,7 +1398,7 @@ Returns a L<Net::Stripe::Invoice>
 
 =back
 
-Returns a L<Net::Stripe::Invoice>
+Returns a L<Net::Stripe::Invoice>.
 
   $stripe->get_invoice(invoice_id => 'testinvoice');
 
@@ -1455,13 +1410,13 @@ Returns a L<Net::Stripe::Invoice>
 
 =back
 
-Returns a L<Net::Stripe::Invoice>
+Returns a L<Net::Stripe::Invoice>.
 
   $stripe->pay_invoice(invoice_id => 'testinvoice');
 
 =head2 get_invoices
 
-Returns a list of invoices
+Returns a list of invoices.
 
 L<https://stripe.com/docs/api#list_customer_invoices>
 
@@ -1485,7 +1440,7 @@ Returns a L<Net::Stripe::List> object containing L<Net::Stripe::Invoice> objects
 
 =head2 create_invoice
 
-Create a new invoice
+Create a new invoice.
 
 L<https://stripe.com/docs/api#create_invoice>
 
@@ -1503,7 +1458,7 @@ L<https://stripe.com/docs/api#create_invoice>
 
 =back
 
-Returns a L<Net::Stripe::Invoice>
+Returns a L<Net::Stripe::Invoice>.
 
   $stripe->create_invoice(customer => 'custid', description => 'test');
 
@@ -1515,7 +1470,7 @@ Returns a L<Net::Stripe::Invoice>
 
 =back
 
-Returns a L<Net::Stripe::Invoice>
+Returns a L<Net::Stripe::Invoice>.
 
   $stripe->get_invoice(invoice_id => 'test');
 
@@ -1527,7 +1482,7 @@ Returns a L<Net::Stripe::Invoice>
 
 =back
 
-Returns a L<Net::Stripe::Invoice>
+Returns a L<Net::Stripe::Invoice>.
 
   $stripe->get_upcominginvoice(customer => $customer);
 
@@ -1557,7 +1512,7 @@ L<https://stripe.com/docs/api#create_invoiceitem>
 
 =back
 
-Returns a L<Net::Stripe::Invoiceitem> object
+Returns a L<Net::Stripe::Invoiceitem> object.
 
   $stripe->create_invoiceitem(customer => 'test', amount => 500, currency => 'USD');
 
@@ -1579,7 +1534,7 @@ L<https://stripe.com/docs/api#create_invoiceitem>
 
 =back
 
-Returns a L<Net::Stripe::Invoiceitem>
+Returns a L<Net::Stripe::Invoiceitem>.
 
   $stripe->post_invoiceitem(invoice_item => 'itemid', amount => 750);
 
@@ -1593,13 +1548,13 @@ Retrieve an invoice item.
 
 =back
 
-Returns a L<Net::Stripe::Invoiceitem>
+Returns a L<Net::Stripe::Invoiceitem>.
 
   $stripe->get_invoiceitem(invoice_item => 'testitemid');
 
 =head2 delete_invoiceitem
 
-Delete an invoice item
+Delete an invoice item.
 
 =over
 
@@ -1607,7 +1562,7 @@ Delete an invoice item
 
 =back
 
-Returns a L<Net::Stripe::Invoiceitem>
+Returns a L<Net::Stripe::Invoiceitem>.
 
   $stripe->delete_invoiceitem(invoice_item => $invoice_item);
 
@@ -1633,7 +1588,7 @@ Returns a L<Net::Stripe::List> object containing L<Net::Stripe::Invoiceitem> obj
 
 =discount_method delete_customer_discount
 
-Deleting a Customer-wide Discount
+Deletes a customer-wide discount.
 
 L<https://stripe.com/docs/api/curl#delete_discount>
 
@@ -1645,7 +1600,7 @@ L<https://stripe.com/docs/api/curl#delete_discount>
 
   $stripe->delete_customer_discount(customer => $customer);
 
-returns hashref of the form
+Returns hashref of the form
 
   {
     deleted => <bool>
@@ -1671,12 +1626,16 @@ Rusty Conover
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Solomon Brian Collins Devin M. Certas Dimitar Petrov Dylan Reinhold Hermann Calabria Jonathan "Duke" Leto Luke Closs Olaf Alders Paul Cochrane Rusty Conover Tom Eliaz
+=for stopwords Andrew Solomon Brian Collins Devin M. Certas Dimitar Petrov Dylan Reinhold Hermann Calabria Jonathan "Duke" Leto Luke Closs Mohammad S Anwar Olaf Alders Paul Cochrane Rusty Conover Sachin Sebastian Tom Eliaz
 
 =over 4
 
 =item *
 
+Andrew Solomon <andrew@geekuni.com>
+
+=item *
+
 Andrew Solomon <andrew@illywhacker.net>
 
 =item *
@@ -1709,6 +1668,10 @@ Luke Closs <me@luk.ec>
 
 =item *
 
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -1721,13 +1684,17 @@ Rusty Conover <rusty@luckydinosaur.com>
 
 =item *
 
+Sachin Sebastian <sachinjsk@users.noreply.github.com>
+
+=item *
+
 Tom Eliaz <tom@tomeliaz.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
