@@ -1,5 +1,5 @@
 package Net::Stripe::BalanceTransaction;
-$Net::Stripe::BalanceTransaction::VERSION = '0.30';
+$Net::Stripe::BalanceTransaction::VERSION = '0.31';
 use Moose;
 use Moose::Util::TypeConstraints qw(subtype as where message);
 extends 'Net::Stripe::Resource';
@@ -42,83 +42,7 @@ Net::Stripe::BalanceTransaction - represent a BalanceTransaction object from Str
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 amount
-
-Reader: amount
-
-Type: Int
-
-=head2 available_on
-
-Reader: available_on
-
-Type: Int
-
-=head2 created
-
-Reader: created
-
-Type: Int
-
-=head2 currency
-
-Reader: currency
-
-Type: Str
-
-This attribute is required.
-
-=head2 description
-
-Reader: description
-
-Type: Maybe[Str]
-
-=head2 fee
-
-Reader: fee
-
-Type: Int
-
-=head2 fee_details
-
-Reader: fee_details
-
-Type: Maybe[ArrayRef]
-
-=head2 id
-
-Reader: id
-
-Type: Str
-
-=head2 net
-
-Reader: net
-
-Type: Int
-
-=head2 source
-
-Reader: source
-
-Type: Str
-
-=head2 status
-
-Reader: status
-
-Type: StatusType
-
-=head2 type
-
-Reader: type
-
-Type: TransactionType
+version 0.31
 
 =head1 AUTHORS
 
@@ -136,7 +60,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
