@@ -1,5 +1,5 @@
 package Net::Stripe::Coupon;
-$Net::Stripe::Coupon::VERSION = '0.30';
+$Net::Stripe::Coupon::VERSION = '0.31';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Kavorka;
@@ -36,61 +36,7 @@ Net::Stripe::Coupon - represent a Coupon object from Stripe
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 duration
-
-Reader: duration
-
-Writer: duration
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 duration_in_months
-
-Reader: duration_in_months
-
-Writer: duration_in_months
-
-Type: Maybe[Int]
-
-=head2 id
-
-Reader: id
-
-Writer: id
-
-Type: Maybe[Str]
-
-=head2 max_redemptions
-
-Reader: max_redemptions
-
-Writer: max_redemptions
-
-Type: Maybe[Int]
-
-=head2 percent_off
-
-Reader: percent_off
-
-Writer: percent_off
-
-Type: Maybe[Int]
-
-This attribute is required.
-
-=head2 redeem_by
-
-Reader: redeem_by
-
-Writer: redeem_by
-
-Type: Maybe[Int]
+version 0.31
 
 =head1 AUTHORS
 
@@ -108,7 +54,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
