@@ -1,5 +1,5 @@
 package Net::Stripe::Discount;
-$Net::Stripe::Discount::VERSION = '0.30';
+$Net::Stripe::Discount::VERSION = '0.31';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Kavorka;
@@ -23,25 +23,7 @@ Net::Stripe::Discount - represent a Discount object from Stripe
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 coupon
-
-Reader: coupon
-
-Writer: coupon
-
-Type: Maybe[Net::Stripe::Coupon]
-
-=head2 start
-
-Reader: start
-
-Writer: start
-
-Type: Maybe[Int]
+version 0.31
 
 =head1 AUTHORS
 
@@ -59,7 +41,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
