@@ -1,5 +1,5 @@
 package Net::Stripe::Error;
-$Net::Stripe::Error::VERSION = '0.30';
+$Net::Stripe::Error::VERSION = '0.31';
 use Moose;
 with 'Throwable';
 use namespace::clean -except => 'meta';
@@ -33,41 +33,7 @@ Net::Stripe::Error - represent an error result from interacting with Stripe
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 code
-
-Reader: code
-
-Type: Maybe[Str]
-
-=head2 message
-
-Reader: message
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 param
-
-Reader: param
-
-Type: Maybe[Str]
-
-=head2 previous_exception
-
-Reader: previous_exception
-
-=head2 type
-
-Reader: type
-
-Type: Maybe[Str]
-
-This attribute is required.
+version 0.31
 
 =head1 AUTHORS
 
@@ -85,7 +51,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
