@@ -1,5 +1,5 @@
 package Net::Stripe::Invoiceitem;
-$Net::Stripe::Invoiceitem::VERSION = '0.30';
+$Net::Stripe::Invoiceitem::VERSION = '0.31';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -39,71 +39,7 @@ Net::Stripe::Invoiceitem - represent an Invoice Item object from Stripe
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 amount
-
-Reader: amount
-
-Writer: amount
-
-Type: Maybe[Int]
-
-This attribute is required.
-
-=head2 currency
-
-Reader: currency
-
-Writer: currency
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 customer
-
-Reader: customer
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 date
-
-Reader: date
-
-Type: Maybe[Int]
-
-=head2 description
-
-Reader: description
-
-Writer: description
-
-Type: Maybe[Str]
-
-=head2 id
-
-Reader: id
-
-Type: Maybe[Str]
-
-=head2 invoice
-
-Reader: invoice
-
-Type: Maybe[Str]
-
-=head2 metadata
-
-Reader: metadata
-
-Writer: metadata
-
-Type: Maybe[HashRef]
+version 0.31
 
 =head1 AUTHORS
 
@@ -121,7 +57,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
