@@ -1,5 +1,5 @@
 package Net::Stripe::List;
-$Net::Stripe::List::VERSION = '0.30';
+$Net::Stripe::List::VERSION = '0.31';
 use Moose;
 use Kavorka;
 
@@ -40,39 +40,7 @@ Net::Stripe::List - represent a list of objects from Stripe
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 count
-
-Reader: count
-
-Type: Maybe[Int]
-
-=head2 data
-
-Reader: data
-
-Type: ArrayRef
-
-This attribute is required.
-
-=head2 has_more
-
-Reader: has_more
-
-Type: Bool|Object
-
-This attribute is required.
-
-=head2 url
-
-Reader: url
-
-Type: Str
-
-This attribute is required.
+version 0.31
 
 =head1 AUTHORS
 
@@ -90,7 +58,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
