@@ -1,5 +1,5 @@
 package Net::Stripe::Plan;
-$Net::Stripe::Plan::VERSION = '0.30';
+$Net::Stripe::Plan::VERSION = '0.31';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Kavorka;
@@ -42,67 +42,7 @@ Net::Stripe::Plan - represent a Plan object from Stripe
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 amount
-
-Reader: amount
-
-Type: Maybe[Int]
-
-This attribute is required.
-
-=head2 currency
-
-Reader: currency
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 id
-
-Reader: id
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 interval
-
-Reader: interval
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 interval_count
-
-Reader: interval_count
-
-Type: Maybe[Int]
-
-=head2 name
-
-Reader: name
-
-Type: Maybe[Str]
-
-This attribute is required.
-
-=head2 statement_description
-
-Reader: statement_description
-
-Type: Maybe[StatementDescription]
-
-=head2 trial_period_days
-
-Reader: trial_period_days
-
-Type: Maybe[Int]
+version 0.31
 
 =head1 AUTHORS
 
@@ -120,7 +60,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
