@@ -1,5 +1,5 @@
 package Net::Stripe::Token;
-$Net::Stripe::Token::VERSION = '0.30';
+$Net::Stripe::Token::VERSION = '0.31';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -39,53 +39,7 @@ Net::Stripe::Token - represent a Token object from Stripe
 
 =head1 VERSION
 
-version 0.30
-
-=head1 ATTRIBUTES
-
-=head2 amount
-
-Reader: amount
-
-Type: Maybe[Int]
-
-=head2 card
-
-Reader: card
-
-Type: Maybe[Net::Stripe::Card]
-
-This attribute is required.
-
-=head2 created
-
-Reader: created
-
-Type: Maybe[Int]
-
-=head2 currency
-
-Reader: currency
-
-Type: Maybe[Str]
-
-=head2 id
-
-Reader: id
-
-Type: Maybe[Str]
-
-=head2 livemode
-
-Reader: livemode
-
-Type: Maybe[Bool|Object]
-
-=head2 used
-
-Reader: used
-
-Type: Maybe[Bool|Object]
+version 0.31
 
 =head1 AUTHORS
 
@@ -103,7 +57,7 @@ Rusty Conover
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC..
+This software is copyright (c) 2015 by Prime Radiant, Inc., (c) copyright 2014 Lucky Dinosaur LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
